FileManager class Utilitários
Implementação de gerenciamento de arquivos.
Fornece funcionalidades para criar, ler, escrever e deletar arquivos e diretórios. Todas as operações são serializadas por caminho para evitar condições de corrida.
- Implemented types
Constructors
- FileManager()
-
Cria um gerenciador de arquivos para o
fileTypeinformado.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createDirectory(
String path) → Future< bool> -
Cria um diretório em
pathse ele não existir.override -
deleteDirectory(
String path) → Future< bool> -
Remove o diretório em
pathquando ele existir.override -
deleteFile(
String path) → Future< bool> -
Remove o arquivo em
pathquando ele existir.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readFile(
String path) → Future< String> -
Lê e retorna o conteúdo do arquivo em
path.override -
toString(
) → String -
A string representation of this object.
inherited
-
writeFile(
String path, String content) → Future< bool> -
Escreve
contentno arquivo empath.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited